package chartjs-datalabels

  1. Overview
  2. Docs

Module Chartjs_datalabels.AlignSource

Sourcetype t

The label is centered on the anchor point.

The label is positioned before the anchor point, following the same direction.

The label is positioned after the anchor point, following the same direction.

The label is positioned to the right of the anchor point (0°).

The label is positioned to the bottom of the anchor point (90°).

The label is positioned to the left of the anchor point (180°).

The label is positioned to the top of the anchor point (270°).

Sourceval degree : float -> t Js_of_ocaml.Js.t

A number representing the clockwise angle (in degree).